lipd.pkg_resources.doi package
==============================

Submodules
----------

lipd.pkg_resources.doi.doi_main module
--------------------------------------

.. automodule:: lipd.pkg_resources.doi.doi_main
    :members:
    :undoc-members:
    :show-inheritance:

lipd.pkg_resources.doi.doi_resolver module
------------------------------------------

.. automodule:: lipd.pkg_resources.doi.doi_resolver
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: lipd.pkg_resources.doi
    :members:
    :undoc-members:
    :show-inheritance:
